afmformats
==========

|PyPI Version| |Build Status Linux| |Build Status Win| |Coverage Status| |Docs Status|

Reading common atomic force microscopy (AFM) file formats.

Documentation
-------------

The documentation, including the code reference and examples, is available at
`afmformats.readthedocs.io <https://afmformats.readthedocs.io/en/stable/>`__.


Installation
------------
To install the latest release, simply run:

::

    pip install afmformats


.. |PyPI Version| image:: https://img.shields.io/pypi/v/afmformats.svg
   :target: https://pypi.python.org/pypi/afmformats
.. |Build Status Linux| image:: https://img.shields.io/travis/AFM-analysis/afmformats.svg?label=build_linux
   :target: https://travis-ci.org/AFM-analysis/afmformats
.. |Build Status Win| image:: https://img.shields.io/appveyor/ci/paulmueller/afmformats/master.svg?label=build_win
   :target: https://ci.appveyor.com/project/paulmueller/afmformats
.. |Coverage Status| image:: https://img.shields.io/codecov/c/github/AFM-analysis/afmformats/master.svg
   :target: https://codecov.io/gh/AFM-analysis/afmformats
.. |Docs Status| image:: https://readthedocs.org/projects/afmformats/badge/?version=latest
   :target: https://readthedocs.org/projects/afmformats/builds/
